==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_entities/meterreading_001/MeterReading.java <==

package net.datastream.schemas.mp_entities.meterreading_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.UOMID_Type;
import net.datastream.schemas.mp_fields.WOID_Type;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TARGETEQUIPMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USAGEUOMID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}READINGDATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELATEDWORKORDERID" minOccurs="0"/>
 *         &lt;choice>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTUALREADING"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}DIFFERENCEREADING"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "targetequipmentid",
    "usageuomid",
    "readingdate",
    "workorderid",
    "relatedworkorderid",
    "actualreading",
    "differencereading"
})
@XmlRootElement(name = "MeterReading")
public class MeterReading {

    @XmlElement(name = "TARGETEQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected EQUIPMENTID_Type targetequipmentid;
    @XmlElement(name = "USAGEUOMID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected UOMID_Type usageuomid;
    @XmlElement(name = "READINGDATE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected DATETIME readingdate;
    @XmlElement(name = "WORKORDERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected WOID_Type workorderid;
    @XmlElement(name = "RELATEDWORKORDERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected WOID_Type relatedworkorderid;
    @XmlElement(name = "ACTUALREADING", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY actualreading;
    @XmlElement(name = "DIFFERENCEREADING", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY differencereading;

    /**
     * Gets the value of the targetequipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getTARGETEQUIPMENTID() {
        return targetequipmentid;
    }

    /**
     * Sets the value of the targetequipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setTARGETEQUIPMENTID(EQUIPMENTID_Type value) {
        this.targetequipmentid = value;
    }

    /**
     * Gets the value of the usageuomid property.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getUSAGEUOMID() {
        return usageuomid;
    }

    /**
     * Sets the value of the usageuomid property.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setUSAGEUOMID(UOMID_Type value) {
        this.usageuomid = value;
    }

    /**
     * Gets the value of the readingdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getREADINGDATE() {
        return readingdate;
    }

    /**
     * Sets the value of the readingdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setREADINGDATE(DATETIME value) {
        this.readingdate = value;
    }

    /**
     * Gets the value of the workorderid property.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getWORKORDERID() {
        return workorderid;
    }

    /**
     * Sets the value of the workorderid property.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setWORKORDERID(WOID_Type value) {
        this.workorderid = value;
    }

    /**
     * Gets the value of the relatedworkorderid property.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getRELATEDWORKORDERID() {
        return relatedworkorderid;
    }

    /**
     * Sets the value of the relatedworkorderid property.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setRELATEDWORKORDERID(WOID_Type value) {
        this.relatedworkorderid = value;
    }

    /**
     * Gets the value of the actualreading property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getACTUALREADING() {
        return actualreading;
    }

    /**
     * Sets the value of the actualreading property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setACTUALREADING(QUANTITY value) {
        this.actualreading = value;
    }

    /**
     * Gets the value of the differencereading property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDIFFERENCEREADING() {
        return differencereading;
    }

    /**
     * Sets the value of the differencereading property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDIFFERENCEREADING(QUANTITY value) {
        this.differencereading = value;
    }

}

==> eam-wshub-proxyclient-11.4-9-sources.jar: net/datastream/schemas/mp_entities/meterreading_001/MeterReading.java <==

package net.datastream.schemas.mp_entities.meterreading_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.UOMID_Type;
import net.datastream.schemas.mp_fields.WOID_Type;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TARGETEQUIPMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USAGEUOMID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}READINGDATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELATEDWORKORDERID" minOccurs="0"/>
 *         &lt;choice>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTUALREADING"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}DIFFERENCEREADING"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "targetequipmentid",
    "usageuomid",
    "readingdate",
    "workorderid",
    "relatedworkorderid",
    "actualreading",
    "differencereading"
})
@XmlRootElement(name = "MeterReading")
public class MeterReading {

    @XmlElement(name = "TARGETEQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected EQUIPMENTID_Type targetequipmentid;
    @XmlElement(name = "USAGEUOMID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected UOMID_Type usageuomid;
    @XmlElement(name = "READINGDATE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected DATETIME readingdate;
    @XmlElement(name = "WORKORDERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected WOID_Type workorderid;
    @XmlElement(name = "RELATEDWORKORDERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected WOID_Type relatedworkorderid;
    @XmlElement(name = "ACTUALREADING", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY actualreading;
    @XmlElement(name = "DIFFERENCEREADING", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY differencereading;

    /**
     * Obtient la valeur de la propriété targetequipmentid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getTARGETEQUIPMENTID() {
        return targetequipmentid;
    }

    /**
     * Définit la valeur de la propriété targetequipmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setTARGETEQUIPMENTID(EQUIPMENTID_Type value) {
        this.targetequipmentid = value;
    }

    /**
     * Obtient la valeur de la propriété usageuomid.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getUSAGEUOMID() {
        return usageuomid;
    }

    /**
     * Définit la valeur de la propriété usageuomid.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setUSAGEUOMID(UOMID_Type value) {
        this.usageuomid = value;
    }

    /**
     * Obtient la valeur de la propriété readingdate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getREADINGDATE() {
        return readingdate;
    }

    /**
     * Définit la valeur de la propriété readingdate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setREADINGDATE(DATETIME value) {
        this.readingdate = value;
    }

    /**
     * Obtient la valeur de la propriété workorderid.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getWORKORDERID() {
        return workorderid;
    }

    /**
     * Définit la valeur de la propriété workorderid.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setWORKORDERID(WOID_Type value) {
        this.workorderid = value;
    }

    /**
     * Obtient la valeur de la propriété relatedworkorderid.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getRELATEDWORKORDERID() {
        return relatedworkorderid;
    }

    /**
     * Définit la valeur de la propriété relatedworkorderid.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setRELATEDWORKORDERID(WOID_Type value) {
        this.relatedworkorderid = value;
    }

    /**
     * Obtient la valeur de la propriété actualreading.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getACTUALREADING() {
        return actualreading;
    }

    /**
     * Définit la valeur de la propriété actualreading.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setACTUALREADING(QUANTITY value) {
        this.actualreading = value;
    }

    /**
     * Obtient la valeur de la propriété differencereading.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDIFFERENCEREADING() {
        return differencereading;
    }

    /**
     * Définit la valeur de la propriété differencereading.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDIFFERENCEREADING(QUANTITY value) {
        this.differencereading = value;
    }

}
